# Safety Guard
This model worker will check whether the chat history satisfy the safety principles.

## Usage
- The interface follows the LLM API of the LLM_Project
- Input: The chat history to check.
- Output: The original last message with the check result appended.